#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'krenamefiles.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_KRENAMEFILES_H
#define UI_KRENAMEFILES_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "krenamelistview.h"

QT_BEGIN_NAMESPACE

class Ui_KRenameFiles
{
public:
    QHBoxLayout *horizontalLayout_2;
    KRenameListView *fileList;
    QVBoxLayout *verticalLayout;
    QPushButton *buttonAdd;
    QPushButton *buttonRemove;
    QPushButton *buttonRemoveAll;
    QGridLayout *gridLayout;
    QLabel *label;
    QComboBox *comboSort;
    QLabel *labelCustomSort;
    QCheckBox *checkPreview;
    QCheckBox *checkName;
    QLabel *labelCount;
    QSpacerItem *spacerItem;
    QHBoxLayout *hboxLayout;
    QVBoxLayout *vboxLayout;
    QPushButton *buttonUp;
    QPushButton *buttonDown;
    QSpacerItem *spacerItem1;
    QSpacerItem *spacerItem2;

    void setupUi(QWidget *KRenameFiles)
    {
        if (KRenameFiles->objectName().isEmpty())
            KRenameFiles->setObjectName(QStringLiteral("KRenameFiles"));
        KRenameFiles->resize(483, 442);
        horizontalLayout_2 = new QHBoxLayout(KRenameFiles);
        horizontalLayout_2->setObjectName(QStringLiteral("horizontalLayout_2"));
        fileList = new KRenameListView(KRenameFiles);
        fileList->setObjectName(QStringLiteral("fileList"));
        QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
        sizePolicy.setHorizontalStretch(2);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(fileList->sizePolicy().hasHeightForWidth());
        fileList->setSizePolicy(sizePolicy);
        fileList->setSizeIncrement(QSize(0, 0));
        fileList->setAcceptDrops(true);
        fileList->setEditTriggers(QAbstractItemView::NoEditTriggers);
        fileList->setDragDropMode(QAbstractItemView::DragDrop);
        fileList->setAlternatingRowColors(true);
        fileList->setSelectionMode(QAbstractItemView::ExtendedSelection);
        fileList->setUniformItemSizes(true);

        horizontalLayout_2->addWidget(fileList);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName(QStringLiteral("verticalLayout"));
        buttonAdd = new QPushButton(KRenameFiles);
        buttonAdd->setObjectName(QStringLiteral("buttonAdd"));

        verticalLayout->addWidget(buttonAdd);

        buttonRemove = new QPushButton(KRenameFiles);
        buttonRemove->setObjectName(QStringLiteral("buttonRemove"));

        verticalLayout->addWidget(buttonRemove);

        buttonRemoveAll = new QPushButton(KRenameFiles);
        buttonRemoveAll->setObjectName(QStringLiteral("buttonRemoveAll"));

        verticalLayout->addWidget(buttonRemoveAll);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        label = new QLabel(KRenameFiles);
        label->setObjectName(QStringLiteral("label"));

        gridLayout->addWidget(label, 0, 0, 1, 1);

        comboSort = new QComboBox(KRenameFiles);
        comboSort->setObjectName(QStringLiteral("comboSort"));

        gridLayout->addWidget(comboSort, 0, 1, 1, 1);

        labelCustomSort = new QLabel(KRenameFiles);
        labelCustomSort->setObjectName(QStringLiteral("labelCustomSort"));

        gridLayout->addWidget(labelCustomSort, 1, 1, 1, 1);


        verticalLayout->addLayout(gridLayout);

        checkPreview = new QCheckBox(KRenameFiles);
        checkPreview->setObjectName(QStringLiteral("checkPreview"));

        verticalLayout->addWidget(checkPreview);

        checkName = new QCheckBox(KRenameFiles);
        checkName->setObjectName(QStringLiteral("checkName"));
        checkName->setChecked(true);

        verticalLayout->addWidget(checkName);

        labelCount = new QLabel(KRenameFiles);
        labelCount->setObjectName(QStringLiteral("labelCount"));

        verticalLayout->addWidget(labelCount);

        spacerItem = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout->addItem(spacerItem);

        hboxLayout = new QHBoxLayout();
#ifndef UI_Q_OS_MAC
        hboxLayout->setSpacing(6);
#endif
        hboxLayout->setContentsMargins(0, 0, 0, 0);
        hboxLayout->setObjectName(QStringLiteral("hboxLayout"));
        vboxLayout = new QVBoxLayout();
#ifndef UI_Q_OS_MAC
        vboxLayout->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        vboxLayout->setContentsMargins(0, 0, 0, 0);
#endif
        vboxLayout->setObjectName(QStringLiteral("vboxLayout"));
        buttonUp = new QPushButton(KRenameFiles);
        buttonUp->setObjectName(QStringLiteral("buttonUp"));

        vboxLayout->addWidget(buttonUp);

        buttonDown = new QPushButton(KRenameFiles);
        buttonDown->setObjectName(QStringLiteral("buttonDown"));

        vboxLayout->addWidget(buttonDown);


        hboxLayout->addLayout(vboxLayout);

        spacerItem1 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout->addItem(spacerItem1);


        verticalLayout->addLayout(hboxLayout);

        spacerItem2 = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout->addItem(spacerItem2);


        horizontalLayout_2->addLayout(verticalLayout);

#ifndef UI_QT_NO_SHORTCUT
        label->setBuddy(comboSort);
#endif // QT_NO_SHORTCUT

        retranslateUi(KRenameFiles);

        buttonAdd->setDefault(true);


        QMetaObject::connectSlotsByName(KRenameFiles);
    } // setupUi

    void retranslateUi(QWidget *KRenameFiles)
    {
#ifndef UI_QT_NO_TOOLTIP
        buttonAdd->setToolTip(tr2i18n("Add files for renaming.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        buttonAdd->setText(tr2i18n("&Add...", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        buttonRemove->setToolTip(tr2i18n("Remove selected files.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        buttonRemove->setText(tr2i18n("Re&move", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        buttonRemoveAll->setToolTip(tr2i18n("Remove all files.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        buttonRemoveAll->setText(tr2i18n("Re&move All", Q_NULLPTR));
        label->setText(tr2i18n("Sort:", Q_NULLPTR));
        comboSort->clear();
        comboSort->insertItems(0, QStringList()
         << tr2i18n("Unsorted", Q_NULLPTR)
         << tr2i18n("Ascending", Q_NULLPTR)
         << tr2i18n("Descending", Q_NULLPTR)
         << tr2i18n("Numeric", Q_NULLPTR)
         << tr2i18n("Random", Q_NULLPTR)
         << tr2i18n("Date (Asc.)", Q_NULLPTR)
         << tr2i18n("Date (Desc.)", Q_NULLPTR)
         << tr2i18n("Custom ...", Q_NULLPTR)
        );
        labelCustomSort->setText(QString());
#ifndef UI_QT_NO_TOOLTIP
        checkPreview->setToolTip(tr2i18n("Display a preview image for each file.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        checkPreview->setText(tr2i18n("&Preview", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        checkName->setToolTip(tr2i18n("Display the filename together with the preview.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        checkName->setText(tr2i18n("&Display name", Q_NULLPTR));
        labelCount->setText(tr2i18n("Files: <b>0</b>", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        buttonUp->setToolTip(tr2i18n("Move selected files upwards.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        buttonUp->setText(tr2i18n("Up", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        buttonDown->setToolTip(tr2i18n("Move selected files downwards.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        buttonDown->setText(tr2i18n("Down", Q_NULLPTR));
        Q_UNUSED(KRenameFiles);
    } // retranslateUi

};

namespace Ui {
    class KRenameFiles: public Ui_KRenameFiles {};
} // namespace Ui

QT_END_NAMESPACE

#endif // KRENAMEFILES_H

