#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'dirsortpluginwidget.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DIRSORTPLUGINWIDGET_H
#define UI_DIRSORTPLUGINWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_DirSortPluginWidget
{
public:
    QVBoxLayout *verticalLayout_2;
    QLabel *label;
    QGroupBox *groupBox;
    QGridLayout *gridLayout;
    QLabel *label_2;
    QSpinBox *spinFiles;
    QLabel *label_3;
    QSpinBox *spinStart;
    QLabel *label_4;
    QSpinBox *spinDigits;
    QGroupBox *groupBox_2;
    QVBoxLayout *verticalLayout;
    KUrlRequester *outputUrl;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *DirSortPluginWidget)
    {
        if (DirSortPluginWidget->objectName().isEmpty())
            DirSortPluginWidget->setObjectName(QStringLiteral("DirSortPluginWidget"));
        DirSortPluginWidget->resize(400, 342);
        verticalLayout_2 = new QVBoxLayout(DirSortPluginWidget);
        verticalLayout_2->setObjectName(QStringLiteral("verticalLayout_2"));
        label = new QLabel(DirSortPluginWidget);
        label->setObjectName(QStringLiteral("label"));

        verticalLayout_2->addWidget(label);

        groupBox = new QGroupBox(DirSortPluginWidget);
        groupBox->setObjectName(QStringLiteral("groupBox"));
        gridLayout = new QGridLayout(groupBox);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        label_2 = new QLabel(groupBox);
        label_2->setObjectName(QStringLiteral("label_2"));

        gridLayout->addWidget(label_2, 0, 0, 1, 1);

        spinFiles = new QSpinBox(groupBox);
        spinFiles->setObjectName(QStringLiteral("spinFiles"));
        spinFiles->setMinimum(1);
        spinFiles->setMaximum(65000);

        gridLayout->addWidget(spinFiles, 0, 1, 1, 1);

        label_3 = new QLabel(groupBox);
        label_3->setObjectName(QStringLiteral("label_3"));

        gridLayout->addWidget(label_3, 1, 0, 1, 1);

        spinStart = new QSpinBox(groupBox);
        spinStart->setObjectName(QStringLiteral("spinStart"));
        spinStart->setMaximum(65000);

        gridLayout->addWidget(spinStart, 1, 1, 1, 1);

        label_4 = new QLabel(groupBox);
        label_4->setObjectName(QStringLiteral("label_4"));

        gridLayout->addWidget(label_4, 2, 0, 1, 1);

        spinDigits = new QSpinBox(groupBox);
        spinDigits->setObjectName(QStringLiteral("spinDigits"));
        spinDigits->setMinimum(1);
        spinDigits->setMaximum(255);

        gridLayout->addWidget(spinDigits, 2, 1, 1, 1);


        verticalLayout_2->addWidget(groupBox);

        groupBox_2 = new QGroupBox(DirSortPluginWidget);
        groupBox_2->setObjectName(QStringLiteral("groupBox_2"));
        verticalLayout = new QVBoxLayout(groupBox_2);
        verticalLayout->setObjectName(QStringLiteral("verticalLayout"));
        outputUrl = new KUrlRequester(groupBox_2);
        outputUrl->setObjectName(QStringLiteral("outputUrl"));

        verticalLayout->addWidget(outputUrl);


        verticalLayout_2->addWidget(groupBox_2);

        verticalSpacer = new QSpacerItem(20, 83, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout_2->addItem(verticalSpacer);

#ifndef UI_QT_NO_SHORTCUT
        label_2->setBuddy(spinFiles);
        label_3->setBuddy(spinStart);
        label_4->setBuddy(spinDigits);
#endif // QT_NO_SHORTCUT

        retranslateUi(DirSortPluginWidget);

        QMetaObject::connectSlotsByName(DirSortPluginWidget);
    } // setupUi

    void retranslateUi(QWidget *DirSortPluginWidget)
    {
        label->setText(tr2i18n("This plugin sorts files into numbered subfolders after renaming.\n"
"\n"
"Example:\n"
"	folder/001/file1\n"
"	folder/001/file2\n"
"	folder/002/file3\n"
"	folder/002/file4\n"
"	folder/003/file5\n"
"	...", Q_NULLPTR));
        groupBox->setTitle(tr2i18n("&Options:", Q_NULLPTR));
        label_2->setText(tr2i18n("Number of &files per folder:", Q_NULLPTR));
        label_3->setText(tr2i18n("&Start index:", Q_NULLPTR));
        label_4->setText(tr2i18n("Number &of digits:", Q_NULLPTR));
        groupBox_2->setTitle(tr2i18n("Out&put:", Q_NULLPTR));
        Q_UNUSED(DirSortPluginWidget);
    } // retranslateUi

};

namespace Ui {
    class DirSortPluginWidget: public Ui_DirSortPluginWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // DIRSORTPLUGINWIDGET_H

