#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'krenameplugins.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_KRENAMEPLUGINS_H
#define UI_KRENAMEPLUGINS_H

#include <KItemViews/ktreewidgetsearchlinewidget.h>
#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QSplitter>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_KRenamePlugins
{
public:
    QVBoxLayout *vboxLayout;
    QSplitter *splitter;
    QWidget *layoutWidget;
    QVBoxLayout *vboxLayout1;
    KTreeWidgetSearchLineWidget *searchPlugins;
    QTreeWidget *listPlugins;
    QWidget *widget;
    QVBoxLayout *vboxLayout2;
    QCheckBox *checkEnablePlugin;
    QStackedWidget *stackPlugins;
    QWidget *page;
    QWidget *page_2;

    void setupUi(QWidget *KRenamePlugins)
    {
        if (KRenamePlugins->objectName().isEmpty())
            KRenamePlugins->setObjectName(QStringLiteral("KRenamePlugins"));
        KRenamePlugins->resize(634, 660);
        vboxLayout = new QVBoxLayout(KRenamePlugins);
        vboxLayout->setObjectName(QStringLiteral("vboxLayout"));
        splitter = new QSplitter(KRenamePlugins);
        splitter->setObjectName(QStringLiteral("splitter"));
        splitter->setOrientation(Qt::Horizontal);
        layoutWidget = new QWidget(splitter);
        layoutWidget->setObjectName(QStringLiteral("layoutWidget"));
        vboxLayout1 = new QVBoxLayout(layoutWidget);
        vboxLayout1->setObjectName(QStringLiteral("vboxLayout1"));
        vboxLayout1->setContentsMargins(0, 0, 0, 0);
        searchPlugins = new KTreeWidgetSearchLineWidget(layoutWidget);
        searchPlugins->setObjectName(QStringLiteral("searchPlugins"));

        vboxLayout1->addWidget(searchPlugins);

        listPlugins = new QTreeWidget(layoutWidget);
        listPlugins->setObjectName(QStringLiteral("listPlugins"));
        listPlugins->setAlternatingRowColors(true);
        listPlugins->setRootIsDecorated(false);
        listPlugins->setItemsExpandable(false);
        listPlugins->setSortingEnabled(true);
        listPlugins->setAllColumnsShowFocus(true);

        vboxLayout1->addWidget(listPlugins);

        splitter->addWidget(layoutWidget);
        widget = new QWidget(splitter);
        widget->setObjectName(QStringLiteral("widget"));
        vboxLayout2 = new QVBoxLayout(widget);
        vboxLayout2->setObjectName(QStringLiteral("vboxLayout2"));
        vboxLayout2->setContentsMargins(0, 0, 0, 0);
        checkEnablePlugin = new QCheckBox(widget);
        checkEnablePlugin->setObjectName(QStringLiteral("checkEnablePlugin"));
        QSizePolicy sizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(4);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(checkEnablePlugin->sizePolicy().hasHeightForWidth());
        checkEnablePlugin->setSizePolicy(sizePolicy);

        vboxLayout2->addWidget(checkEnablePlugin);

        stackPlugins = new QStackedWidget(widget);
        stackPlugins->setObjectName(QStringLiteral("stackPlugins"));
        QSizePolicy sizePolicy1(QSizePolicy::MinimumExpanding, QSizePolicy::Expanding);
        sizePolicy1.setHorizontalStretch(4);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(stackPlugins->sizePolicy().hasHeightForWidth());
        stackPlugins->setSizePolicy(sizePolicy1);
        stackPlugins->setSizeIncrement(QSize(2, 0));
        page = new QWidget();
        page->setObjectName(QStringLiteral("page"));
        stackPlugins->addWidget(page);
        page_2 = new QWidget();
        page_2->setObjectName(QStringLiteral("page_2"));
        stackPlugins->addWidget(page_2);

        vboxLayout2->addWidget(stackPlugins);

        splitter->addWidget(widget);

        vboxLayout->addWidget(splitter);


        retranslateUi(KRenamePlugins);

        QMetaObject::connectSlotsByName(KRenamePlugins);
    } // setupUi

    void retranslateUi(QWidget *KRenamePlugins)
    {
        QTreeWidgetItem *___qtreewidgetitem = listPlugins->headerItem();
        ___qtreewidgetitem->setText(0, tr2i18n("Plugins", Q_NULLPTR));
        checkEnablePlugin->setText(tr2i18n("&Enable Plugin", Q_NULLPTR));
        Q_UNUSED(KRenamePlugins);
    } // retranslateUi

};

namespace Ui {
    class KRenamePlugins: public Ui_KRenamePlugins {};
} // namespace Ui

QT_END_NAMESPACE

#endif // KRENAMEPLUGINS_H

