#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'partfilenamewidget.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PARTFILENAMEWIDGET_H
#define UI_PARTFILENAMEWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "selectionsafelineedit.h"

QT_BEGIN_NAMESPACE

class Ui_PartFilenameWidget
{
public:
    QVBoxLayout *vboxLayout;
    QFrame *frame;
    QVBoxLayout *vboxLayout1;
    QLabel *label;
    SelectionSafeLineEdit *textFilename;
    QCheckBox *checkInvert;
    QHBoxLayout *hboxLayout;
    QLabel *label_2;
    QComboBox *comboConvert;
    QLabel *labelPreviewDesc;
    QLabel *labelPreview;

    void setupUi(QWidget *PartFilenameWidget)
    {
        if (PartFilenameWidget->objectName().isEmpty())
            PartFilenameWidget->setObjectName(QStringLiteral("PartFilenameWidget"));
        PartFilenameWidget->resize(412, 275);
        vboxLayout = new QVBoxLayout(PartFilenameWidget);
        vboxLayout->setObjectName(QStringLiteral("vboxLayout"));
        frame = new QFrame(PartFilenameWidget);
        frame->setObjectName(QStringLiteral("frame"));
        frame->setFrameShape(QFrame::StyledPanel);
        frame->setFrameShadow(QFrame::Raised);
        vboxLayout1 = new QVBoxLayout(frame);
        vboxLayout1->setObjectName(QStringLiteral("vboxLayout1"));
        label = new QLabel(frame);
        label->setObjectName(QStringLiteral("label"));
        label->setWordWrap(true);

        vboxLayout1->addWidget(label);

        textFilename = new SelectionSafeLineEdit(frame);
        textFilename->setObjectName(QStringLiteral("textFilename"));
        textFilename->setReadOnly(true);

        vboxLayout1->addWidget(textFilename);

        checkInvert = new QCheckBox(frame);
        checkInvert->setObjectName(QStringLiteral("checkInvert"));

        vboxLayout1->addWidget(checkInvert);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName(QStringLiteral("hboxLayout"));
        label_2 = new QLabel(frame);
        label_2->setObjectName(QStringLiteral("label_2"));

        hboxLayout->addWidget(label_2);

        comboConvert = new QComboBox(frame);
        comboConvert->setObjectName(QStringLiteral("comboConvert"));

        hboxLayout->addWidget(comboConvert);


        vboxLayout1->addLayout(hboxLayout);

        labelPreviewDesc = new QLabel(frame);
        labelPreviewDesc->setObjectName(QStringLiteral("labelPreviewDesc"));

        vboxLayout1->addWidget(labelPreviewDesc);

        labelPreview = new QLabel(frame);
        labelPreview->setObjectName(QStringLiteral("labelPreview"));

        vboxLayout1->addWidget(labelPreview);


        vboxLayout->addWidget(frame);

#ifndef UI_QT_NO_SHORTCUT
        label->setBuddy(textFilename);
        label_2->setBuddy(comboConvert);
#endif // QT_NO_SHORTCUT

        retranslateUi(PartFilenameWidget);

        QMetaObject::connectSlotsByName(PartFilenameWidget);
    } // setupUi

    void retranslateUi(QWidget *PartFilenameWidget)
    {
        label->setText(tr2i18n("<qt>Please select the part of the old filename  which should be inserted into the new filename in the textbox below:</qt>", Q_NULLPTR));
        checkInvert->setText(tr2i18n("&Invert selection", Q_NULLPTR));
        label_2->setText(tr2i18n("&Convert selection:", Q_NULLPTR));
        comboConvert->clear();
        comboConvert->insertItems(0, QStringList()
         << tr2i18n("No Conversion", Q_NULLPTR)
         << tr2i18n("Convert to lower case", Q_NULLPTR)
         << tr2i18n("Convert to upper case", Q_NULLPTR)
         << tr2i18n("Capitalize", Q_NULLPTR)
        );
        labelPreviewDesc->setText(tr2i18n("Preview of the generated KRename command:", Q_NULLPTR));
        labelPreview->setText(tr2i18n("TextLabel", "KDE::DoNotExtract"));
        Q_UNUSED(PartFilenameWidget);
    } // retranslateUi

};

namespace Ui {
    class PartFilenameWidget: public Ui_PartFilenameWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PARTFILENAMEWIDGET_H

