/****************************************************************************
** Meta object code from reading C++ file 'krenameimpl.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/krename-5.0.0/src/krenameimpl.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'krenameimpl.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KRenameImpl_t {
    QByteArrayData data[23];
    char stringdata0[324];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KRenameImpl_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KRenameImpl_t qt_meta_stringdata_KRenameImpl = {
    {
QT_MOC_LITERAL(0, 0, 11), // "KRenameImpl"
QT_MOC_LITERAL(1, 12, 17), // "slotUpdatePreview"
QT_MOC_LITERAL(2, 30, 0), // ""
QT_MOC_LITERAL(3, 31, 10), // "saveConfig"
QT_MOC_LITERAL(4, 42, 8), // "selfTest"
QT_MOC_LITERAL(5, 51, 12), // "slotAddFiles"
QT_MOC_LITERAL(6, 64, 15), // "slotRemoveFiles"
QT_MOC_LITERAL(7, 80, 18), // "slotRemoveAllFiles"
QT_MOC_LITERAL(8, 99, 15), // "slotUpdateCount"
QT_MOC_LITERAL(9, 115, 24), // "slotAdvancedNumberingDlg"
QT_MOC_LITERAL(10, 140, 25), // "slotInsertPartFilenameDlg"
QT_MOC_LITERAL(11, 166, 18), // "slotFindReplaceDlg"
QT_MOC_LITERAL(12, 185, 9), // "slotStart"
QT_MOC_LITERAL(13, 195, 14), // "slotListerDone"
QT_MOC_LITERAL(14, 210, 15), // "ThreadedLister*"
QT_MOC_LITERAL(15, 226, 6), // "lister"
QT_MOC_LITERAL(16, 233, 19), // "slotTokenHelpDialog"
QT_MOC_LITERAL(17, 253, 10), // "QLineEdit*"
QT_MOC_LITERAL(18, 264, 4), // "edit"
QT_MOC_LITERAL(19, 269, 29), // "slotExtensionSplitModeChanged"
QT_MOC_LITERAL(20, 299, 10), // "ESplitMode"
QT_MOC_LITERAL(21, 310, 9), // "splitMode"
QT_MOC_LITERAL(22, 320, 3) // "dot"

    },
    "KRenameImpl\0slotUpdatePreview\0\0"
    "saveConfig\0selfTest\0slotAddFiles\0"
    "slotRemoveFiles\0slotRemoveAllFiles\0"
    "slotUpdateCount\0slotAdvancedNumberingDlg\0"
    "slotInsertPartFilenameDlg\0slotFindReplaceDlg\0"
    "slotStart\0slotListerDone\0ThreadedLister*\0"
    "lister\0slotTokenHelpDialog\0QLineEdit*\0"
    "edit\0slotExtensionSplitModeChanged\0"
    "ESplitMode\0splitMode\0dot"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KRenameImpl[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      14,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   84,    2, 0x0a /* Public */,
       3,    0,   85,    2, 0x08 /* Private */,
       4,    0,   86,    2, 0x08 /* Private */,
       5,    0,   87,    2, 0x08 /* Private */,
       6,    0,   88,    2, 0x08 /* Private */,
       7,    0,   89,    2, 0x08 /* Private */,
       8,    0,   90,    2, 0x08 /* Private */,
       9,    0,   91,    2, 0x08 /* Private */,
      10,    0,   92,    2, 0x08 /* Private */,
      11,    0,   93,    2, 0x08 /* Private */,
      12,    0,   94,    2, 0x08 /* Private */,
      13,    1,   95,    2, 0x08 /* Private */,
      16,    1,   98,    2, 0x08 /* Private */,
      19,    2,  101,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 14,   15,
    QMetaType::Void, 0x80000000 | 17,   18,
    QMetaType::Void, 0x80000000 | 20, QMetaType::Int,   21,   22,

       0        // eod
};

void KRenameImpl::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KRenameImpl *_t = static_cast<KRenameImpl *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->slotUpdatePreview(); break;
        case 1: _t->saveConfig(); break;
        case 2: _t->selfTest(); break;
        case 3: _t->slotAddFiles(); break;
        case 4: _t->slotRemoveFiles(); break;
        case 5: _t->slotRemoveAllFiles(); break;
        case 6: _t->slotUpdateCount(); break;
        case 7: _t->slotAdvancedNumberingDlg(); break;
        case 8: _t->slotInsertPartFilenameDlg(); break;
        case 9: _t->slotFindReplaceDlg(); break;
        case 10: _t->slotStart(); break;
        case 11: _t->slotListerDone((*reinterpret_cast< ThreadedLister*(*)>(_a[1]))); break;
        case 12: _t->slotTokenHelpDialog((*reinterpret_cast< QLineEdit*(*)>(_a[1]))); break;
        case 13: _t->slotExtensionSplitModeChanged((*reinterpret_cast< ESplitMode(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        default: ;
        }
    }
}

const QMetaObject KRenameImpl::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_KRenameImpl.data,
      qt_meta_data_KRenameImpl,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KRenameImpl::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KRenameImpl::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KRenameImpl.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KRenameImpl::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 14;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
