#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'increasecounterpluginwidget.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_INCREASECOUNTERPLUGINWIDGET_H
#define UI_INCREASECOUNTERPLUGINWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_IncreaseCounterPluginWidget
{
public:
    QVBoxLayout *verticalLayout_2;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout;
    QLabel *label;
    QSpacerItem *verticalSpacer_2;
    QHBoxLayout *horizontalLayout;
    QLabel *label_2;
    QSpinBox *spinOffset;
    QSpacerItem *verticalSpacer_3;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *IncreaseCounterPluginWidget)
    {
        if (IncreaseCounterPluginWidget->objectName().isEmpty())
            IncreaseCounterPluginWidget->setObjectName(QStringLiteral("IncreaseCounterPluginWidget"));
        IncreaseCounterPluginWidget->resize(512, 388);
        verticalLayout_2 = new QVBoxLayout(IncreaseCounterPluginWidget);
        verticalLayout_2->setObjectName(QStringLiteral("verticalLayout_2"));
        groupBox = new QGroupBox(IncreaseCounterPluginWidget);
        groupBox->setObjectName(QStringLiteral("groupBox"));
        verticalLayout = new QVBoxLayout(groupBox);
        verticalLayout->setObjectName(QStringLiteral("verticalLayout"));
        label = new QLabel(groupBox);
        label->setObjectName(QStringLiteral("label"));
        label->setWordWrap(true);

        verticalLayout->addWidget(label);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout->addItem(verticalSpacer_2);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QStringLiteral("horizontalLayout"));
        label_2 = new QLabel(groupBox);
        label_2->setObjectName(QStringLiteral("label_2"));

        horizontalLayout->addWidget(label_2);

        spinOffset = new QSpinBox(groupBox);
        spinOffset->setObjectName(QStringLiteral("spinOffset"));
        spinOffset->setMinimum(-10000);
        spinOffset->setMaximum(10000);

        horizontalLayout->addWidget(spinOffset);


        verticalLayout->addLayout(horizontalLayout);

        verticalSpacer_3 = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout->addItem(verticalSpacer_3);


        verticalLayout_2->addWidget(groupBox);

        verticalSpacer = new QSpacerItem(20, 94, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout_2->addItem(verticalSpacer);

#ifndef UI_QT_NO_SHORTCUT
        label_2->setBuddy(spinOffset);
#endif // QT_NO_SHORTCUT

        retranslateUi(IncreaseCounterPluginWidget);

        QMetaObject::connectSlotsByName(IncreaseCounterPluginWidget);
    } // setupUi

    void retranslateUi(QWidget *IncreaseCounterPluginWidget)
    {
        groupBox->setTitle(tr2i18n("&Increase Counter", Q_NULLPTR));
        label->setText(tr2i18n("<p><b>This plugin adds a given offset to numbers in filenames.</b><br/>\n"
"E.g. you have the filenames: <i>img014</i>, <i>img015</i>, <i>img023</i> which should be named <i>img010</i>, <i>img011</i> and <i>img019</i>. Using this plugin, you can easily add an offset of -4 to get the desired result.</p>", Q_NULLPTR));
        label_2->setText(tr2i18n("Offse&t:", Q_NULLPTR));
        Q_UNUSED(IncreaseCounterPluginWidget);
    } // retranslateUi

};

namespace Ui {
    class IncreaseCounterPluginWidget: public Ui_IncreaseCounterPluginWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // INCREASECOUNTERPLUGINWIDGET_H

