#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'datetimepluginwidget.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DATETIMEPLUGINWIDGET_H
#define UI_DATETIMEPLUGINWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "kdatepicker.h"

QT_BEGIN_NAMESPACE

class Ui_DateTimePluginWidget
{
public:
    QVBoxLayout *vboxLayout;
    KDatePicker *datepicker;
    QCheckBox *checkAccess;
    QCheckBox *checkModification;
    QHBoxLayout *hboxLayout;
    QLabel *label;
    QSpinBox *spinHour;
    QSpinBox *spinMinute;
    QSpinBox *spinSecond;
    QPushButton *buttonCurrent;

    void setupUi(QWidget *DateTimePluginWidget)
    {
        if (DateTimePluginWidget->objectName().isEmpty())
            DateTimePluginWidget->setObjectName(QStringLiteral("DateTimePluginWidget"));
        DateTimePluginWidget->resize(543, 373);
        vboxLayout = new QVBoxLayout(DateTimePluginWidget);
        vboxLayout->setObjectName(QStringLiteral("vboxLayout"));
        datepicker = new KDatePicker(DateTimePluginWidget);
        datepicker->setObjectName(QStringLiteral("datepicker"));

        vboxLayout->addWidget(datepicker);

        checkAccess = new QCheckBox(DateTimePluginWidget);
        checkAccess->setObjectName(QStringLiteral("checkAccess"));

        vboxLayout->addWidget(checkAccess);

        checkModification = new QCheckBox(DateTimePluginWidget);
        checkModification->setObjectName(QStringLiteral("checkModification"));

        vboxLayout->addWidget(checkModification);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName(QStringLiteral("hboxLayout"));
        label = new QLabel(DateTimePluginWidget);
        label->setObjectName(QStringLiteral("label"));

        hboxLayout->addWidget(label);

        spinHour = new QSpinBox(DateTimePluginWidget);
        spinHour->setObjectName(QStringLiteral("spinHour"));
        spinHour->setMaximum(23);

        hboxLayout->addWidget(spinHour);

        spinMinute = new QSpinBox(DateTimePluginWidget);
        spinMinute->setObjectName(QStringLiteral("spinMinute"));
        spinMinute->setMaximum(59);

        hboxLayout->addWidget(spinMinute);

        spinSecond = new QSpinBox(DateTimePluginWidget);
        spinSecond->setObjectName(QStringLiteral("spinSecond"));
        spinSecond->setMaximum(59);

        hboxLayout->addWidget(spinSecond);

        buttonCurrent = new QPushButton(DateTimePluginWidget);
        buttonCurrent->setObjectName(QStringLiteral("buttonCurrent"));

        hboxLayout->addWidget(buttonCurrent);


        vboxLayout->addLayout(hboxLayout);


        retranslateUi(DateTimePluginWidget);

        QMetaObject::connectSlotsByName(DateTimePluginWidget);
    } // setupUi

    void retranslateUi(QWidget *DateTimePluginWidget)
    {
        checkAccess->setText(tr2i18n("Change &access date && time", Q_NULLPTR));
        checkModification->setText(tr2i18n("Change &modifcation date && time", Q_NULLPTR));
        label->setText(tr2i18n("Time:", Q_NULLPTR));
        buttonCurrent->setText(tr2i18n("Get &Current Time", Q_NULLPTR));
        Q_UNUSED(DateTimePluginWidget);
    } // retranslateUi

};

namespace Ui {
    class DateTimePluginWidget: public Ui_DateTimePluginWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // DATETIMEPLUGINWIDGET_H

