#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'krenamedestination.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_KRENAMEDESTINATION_H
#define UI_KRENAMEDESTINATION_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <kurlrequester.h>

QT_BEGIN_NAMESPACE

class Ui_KRenameDestination
{
public:
    QVBoxLayout *vboxLayout;
    QGroupBox *groupOptions;
    QVBoxLayout *vboxLayout1;
    QRadioButton *optionRename;
    QRadioButton *optionCopy;
    QRadioButton *optionMove;
    QRadioButton *optionLink;
    KUrlRequester *urlrequester;
    QSpacerItem *spacerItem;
    QCheckBox *checkOverwrite;
    QSpacerItem *spacerItem1;

    void setupUi(QWidget *KRenameDestination)
    {
        if (KRenameDestination->objectName().isEmpty())
            KRenameDestination->setObjectName(QStringLiteral("KRenameDestination"));
        KRenameDestination->resize(533, 451);
        vboxLayout = new QVBoxLayout(KRenameDestination);
        vboxLayout->setSpacing(6);
        vboxLayout->setObjectName(QStringLiteral("vboxLayout"));
        vboxLayout->setContentsMargins(9, 9, 9, 9);
        groupOptions = new QGroupBox(KRenameDestination);
        groupOptions->setObjectName(QStringLiteral("groupOptions"));
        vboxLayout1 = new QVBoxLayout(groupOptions);
        vboxLayout1->setSpacing(6);
        vboxLayout1->setObjectName(QStringLiteral("vboxLayout1"));
        vboxLayout1->setContentsMargins(9, 9, 9, 9);
        optionRename = new QRadioButton(groupOptions);
        optionRename->setObjectName(QStringLiteral("optionRename"));
        optionRename->setChecked(true);

        vboxLayout1->addWidget(optionRename);

        optionCopy = new QRadioButton(groupOptions);
        optionCopy->setObjectName(QStringLiteral("optionCopy"));

        vboxLayout1->addWidget(optionCopy);

        optionMove = new QRadioButton(groupOptions);
        optionMove->setObjectName(QStringLiteral("optionMove"));

        vboxLayout1->addWidget(optionMove);

        optionLink = new QRadioButton(groupOptions);
        optionLink->setObjectName(QStringLiteral("optionLink"));

        vboxLayout1->addWidget(optionLink);

        urlrequester = new KUrlRequester(groupOptions);
        urlrequester->setObjectName(QStringLiteral("urlrequester"));

        vboxLayout1->addWidget(urlrequester);

        spacerItem = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        vboxLayout1->addItem(spacerItem);

        checkOverwrite = new QCheckBox(groupOptions);
        checkOverwrite->setObjectName(QStringLiteral("checkOverwrite"));

        vboxLayout1->addWidget(checkOverwrite);


        vboxLayout->addWidget(groupOptions);

        spacerItem1 = new QSpacerItem(20, 61, QSizePolicy::Minimum, QSizePolicy::Expanding);

        vboxLayout->addItem(spacerItem1);


        retranslateUi(KRenameDestination);

        QMetaObject::connectSlotsByName(KRenameDestination);
    } // setupUi

    void retranslateUi(QWidget *KRenameDestination)
    {
        groupOptions->setTitle(tr2i18n("&Options", Q_NULLPTR));
        optionRename->setText(tr2i18n("&Rename input files", Q_NULLPTR));
        optionCopy->setText(tr2i18n("&Copy files to destination folder", Q_NULLPTR));
        optionMove->setText(tr2i18n("&Move files to destination folder", Q_NULLPTR));
        optionLink->setText(tr2i18n("Create symbolic &links in destination folder", Q_NULLPTR));
        checkOverwrite->setText(tr2i18n("&Overwrite existing files", Q_NULLPTR));
        Q_UNUSED(KRenameDestination);
    } // retranslateUi

};

namespace Ui {
    class KRenameDestination: public Ui_KRenameDestination {};
} // namespace Ui

QT_END_NAMESPACE

#endif // KRENAMEDESTINATION_H

