#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'numberwidget.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_NUMBERWIDGET_H
#define UI_NUMBERWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_NumberWidget
{
public:
    QVBoxLayout *vboxLayout;
    QGroupBox *grouNumbering;
    QVBoxLayout *vboxLayout1;
    QGridLayout *gridLayout;
    QLabel *labelStart;
    QSpinBox *spinStart;
    QLabel *label_2;
    QSpinBox *spinStep;
    QCheckBox *checkReset;
    QGroupBox *groupSkip;
    QHBoxLayout *hboxLayout;
    QListWidget *listSkip;
    QVBoxLayout *vboxLayout2;
    QVBoxLayout *vboxLayout3;
    QPushButton *buttonAdd;
    QPushButton *buttonRemove;
    QSpinBox *spinNumber;
    QSpacerItem *spacerItem;

    void setupUi(QWidget *NumberWidget)
    {
        if (NumberWidget->objectName().isEmpty())
            NumberWidget->setObjectName(QStringLiteral("NumberWidget"));
        NumberWidget->resize(390, 478);
        vboxLayout = new QVBoxLayout(NumberWidget);
        vboxLayout->setObjectName(QStringLiteral("vboxLayout"));
        grouNumbering = new QGroupBox(NumberWidget);
        grouNumbering->setObjectName(QStringLiteral("grouNumbering"));
        vboxLayout1 = new QVBoxLayout(grouNumbering);
        vboxLayout1->setObjectName(QStringLiteral("vboxLayout1"));
        gridLayout = new QGridLayout();
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        labelStart = new QLabel(grouNumbering);
        labelStart->setObjectName(QStringLiteral("labelStart"));

        gridLayout->addWidget(labelStart, 0, 0, 1, 1);

        spinStart = new QSpinBox(grouNumbering);
        spinStart->setObjectName(QStringLiteral("spinStart"));
        spinStart->setMaximum(65000);

        gridLayout->addWidget(spinStart, 0, 1, 1, 1);

        label_2 = new QLabel(grouNumbering);
        label_2->setObjectName(QStringLiteral("label_2"));

        gridLayout->addWidget(label_2, 1, 0, 1, 1);

        spinStep = new QSpinBox(grouNumbering);
        spinStep->setObjectName(QStringLiteral("spinStep"));
        spinStep->setMaximum(65000);

        gridLayout->addWidget(spinStep, 1, 1, 1, 1);


        vboxLayout1->addLayout(gridLayout);

        checkReset = new QCheckBox(grouNumbering);
        checkReset->setObjectName(QStringLiteral("checkReset"));

        vboxLayout1->addWidget(checkReset);


        vboxLayout->addWidget(grouNumbering);

        groupSkip = new QGroupBox(NumberWidget);
        groupSkip->setObjectName(QStringLiteral("groupSkip"));
        hboxLayout = new QHBoxLayout(groupSkip);
        hboxLayout->setObjectName(QStringLiteral("hboxLayout"));
        listSkip = new QListWidget(groupSkip);
        listSkip->setObjectName(QStringLiteral("listSkip"));

        hboxLayout->addWidget(listSkip);

        vboxLayout2 = new QVBoxLayout();
        vboxLayout2->setObjectName(QStringLiteral("vboxLayout2"));
        vboxLayout3 = new QVBoxLayout();
        vboxLayout3->setObjectName(QStringLiteral("vboxLayout3"));
        buttonAdd = new QPushButton(groupSkip);
        buttonAdd->setObjectName(QStringLiteral("buttonAdd"));

        vboxLayout3->addWidget(buttonAdd);

        buttonRemove = new QPushButton(groupSkip);
        buttonRemove->setObjectName(QStringLiteral("buttonRemove"));
        buttonRemove->setEnabled(false);

        vboxLayout3->addWidget(buttonRemove);

        spinNumber = new QSpinBox(groupSkip);
        spinNumber->setObjectName(QStringLiteral("spinNumber"));
        spinNumber->setMaximum(65000);

        vboxLayout3->addWidget(spinNumber);


        vboxLayout2->addLayout(vboxLayout3);

        spacerItem = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        vboxLayout2->addItem(spacerItem);


        hboxLayout->addLayout(vboxLayout2);


        vboxLayout->addWidget(groupSkip);

#ifndef UI_QT_NO_SHORTCUT
        labelStart->setBuddy(spinStart);
        label_2->setBuddy(spinStep);
#endif // QT_NO_SHORTCUT

        retranslateUi(NumberWidget);

        QMetaObject::connectSlotsByName(NumberWidget);
    } // setupUi

    void retranslateUi(QWidget *NumberWidget)
    {
        grouNumbering->setTitle(tr2i18n("&Numbering", Q_NULLPTR));
        labelStart->setText(tr2i18n("Start &index:", Q_NULLPTR));
        label_2->setText(tr2i18n("&Step by:", Q_NULLPTR));
        checkReset->setText(tr2i18n("&Reset counter for every directory", Q_NULLPTR));
        groupSkip->setTitle(tr2i18n("&Skip Numbers", Q_NULLPTR));
        buttonAdd->setText(tr2i18n("&Add Number", Q_NULLPTR));
        buttonRemove->setText(tr2i18n("&Remove Number", Q_NULLPTR));
        Q_UNUSED(NumberWidget);
    } // retranslateUi

};

namespace Ui {
    class NumberWidget: public Ui_NumberWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // NUMBERWIDGET_H

